<?php

use demo\Controllers\BlogController;
use demo\Controllers\FeedbackController;
use demo\Controllers\UserController;
use Silex\Application;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\Response;

//Request::setTrustedProxies(array('127.0.0.1'));

$beforeAllMiddleware = function (Request $request, Application $app) {
  echo "In bAM\n";
};

// This type of global configuration does not apply to mounted controllers,
// which have their own "global" configuration.
$app->before($beforeAllMiddleware);

$app->get('/', function () use ($app) {
  return $app['twig']->render('index.html.twig', []);
})->bind('homepage');

$blogPosts = [
  1 => [
    'date' => '2011-03-29',
    'author' => 'igorw',
    'title' => 'Using Silex',
    'body' => '...It takes time on version changes...',
  ],
  2 => [
    'date' => '2015-03-29',
    'author' => 'igorw',
    'title' => 'Using Silex 2',
    'body' => '...Especialy S1 to S2...',
  ],
];

// Available automatic arguments on controllers: Application, Request.
$app->get('/blogs', function () use ($blogPosts) {
  $output = "<ul>\n";
  foreach ($blogPosts as $post) {
    $output .= "<li>" . $post ['title'] . "</li>\n";
  }
  $output .= "</ul>\n";
  return $output;
});

// Default: http://blog, not http://blog/
$app->get('/blog/{id}', BlogController::class . '::fifiAction')
  ->assert('id', '\d+')
  ->when("request.headers.get('User-Agent') matches '/firefox/i'");
$app->get('/blog/{id}', function (Application $app, $id) use ($blogPosts) {
  if (!isset ($blogPosts [$id])) {
    $app->abort(Response::HTTP_NOT_FOUND, "Post $id does not exist.");
  }
  $post = $blogPosts [$id];
  return "<h1> {$post['title']}</h1>" . "<p> {$post['body']} </p>";
})->assert('id', '\d+')
  ->value('id', 1)
  ->bind('blog_post');

$app->post('/feedback', FeedbackController::class . '::feedbackAction');

$app->get('/user/{user}', UserController::class . '::itemAction')
  ->convert('user', 'converter.user:convert');

$app->error(function (\Exception $e, Request $request, $code) use ($app) {
  if ($app['debug']) {
    return;
  }

  // 404.html, or 40x.html, or 4xx.html, or error.html
  $templates = [
    'errors/' . $code . '.html.twig',
    'errors/' . substr($code, 0, 2) . 'x.html.twig',
    'errors/' . substr($code, 0, 1) . 'xx.html.twig',
    'errors/default.html.twig',
  ];

  return new Response($app['twig']->resolveTemplate($templates)
    ->render(['code' => $code]), $code);
});
